generate_poisson_u32

Function generate_poisson_u32 

pub unsafe fn generate_poisson_u32(
    gen: curandGenerator_t,
    out: *mut u32,
    n: usize,
    lambda: f64,
) -> Result<(), CurandError>
curandGeneratePoisson — fill out with n u32 values drawn from a Poisson distribution parameterised by lambda (f64).

Safety

gen must be live and bound to the same stream/context as the device pointer out. out must point to at least n u32 slots.